@@ -2,16 +2,20 @@
  *                   Material Object Library                   *
  *     Class TII : declaration for TII interaction tensor      *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 0.3.0                   *
+ *                   GNU/linux version 2.0.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright  2005,2006 COLLARD Christophe
+ * copyright  2005,2006, 2008 COLLARD Christophe
  * copyright  2006 PARGUEZ Cristelle
- * copyright  2005,2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
+ * copyright  2005,2006, 2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554)
  * copyright  2005,2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
-/*! \class TII
+/*! \namespace materiol
+    \brief Materials Object Libraries
+*/
+
+/*! \class materiol::TII
     \brief Numerical computation of the interaction tensor \f$T^{II} \f$ for spheroid inclusions
 
     \htmlonly 
@@ -48,14 +52,14 @@
     \f$ \left\{ \begin{aligned} \chi_1 &= \sin\theta \cos\varphi, \\ \chi_2 &= \frac{a}{b} \sin\theta \sin\varphi, \\ \chi_3 &= \frac{a}{c} \cos\theta, \end{aligned} \right. \f$ \n
     where \f$ (\theta,\varphi) \f$ are the spherical coordinates angles and where \f$ (a,b,c) \f$ are the spheroid length.
 
-    (see Omar Fassi-Fehri - Thse de Doctorat d'Etat, ISGMP, LPMM - 1985). \n
+    (see Omar Fassi-Fehri - Th&#232;se de Doctorat d'Etat, ISGMP, LPMM - 1985). \n
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2005, 2006 Christophe COLLARD \n
+    \author copyright \htmlonly &#169; \endhtmlonly 2005, 2006, 2008 Christophe COLLARD \n
             copyright \htmlonly &#169; \endhtmlonly 2006 Cristelle PARGUEZ \n
-            copyright \htmlonly &#169; \endhtmlonly 2005, 2006 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	    copyright \htmlonly &#169; \endhtmlonly 2005, 2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 0.3.0
-    \date 2005-2006
+            copyright \htmlonly &#169; 2005, 2006, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
+	    copyright \htmlonly &#169; 2005, 2006 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
+    \version 2.0.0
+    \date 2005-2008
     \bug none
     \warning none
 */
@@ -73,30 +77,34 @@
 #endif
 
 #if !defined(__VECTORS_H)
-#include "../MOL++/vectors.h"
+#include "MOL++/vectors.h"
 #endif
 
 #if !defined(__MATRIX_H)
-#include "../MOL++/matrix.h"
+#include "MOL++/matrix.h"
 #endif
 
 #if !defined(__TENSOR3_H)
-#include "../MOL++/tensors3.h"
+#include "MOL++/tensors3.h"
 #endif
 
 #if !defined(__TENSOR4_H)
-#include "../MOL++/tensors4.h"
+#include "MOL++/tensors4.h"
 #endif
 
 #if !defined(__INTEGRATION_H)
-#include "../MOL++/integration.h"
+#include "MOL++/integration.h"
 #endif
 
 #if !defined(__ISOTROPIC_ELASTICITY_TENSORS_H)
-#include "isotropic elasticity tensors.h"
+#include "MateriOL++/isotropic elasticity tensors.h"
 #endif
 
 using namespace std;
+using namespace mol;
+
+namespace materiol
+{
 
 
 //==========================
@@ -239,4 +247,7 @@ template <class T> tensor4<T> TII<T>::sphere (const isotropic_elasticity_tensor<
 }
 
 
+}
+
+
 #endif
