@@ -2,7 +2,7 @@
  *                   Materials Object Library                  *
  *Class cubic_tensor : declaration for cubic symmetry materials*
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 0.1.2                   *
+ *                   GNU/linux version 2.0.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright  2006,2008 COLLARD Christophe
@@ -10,7 +10,11 @@
  * copyright  2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
-/*! \class cubic_tensor
+/*! \namespace materiol
+    \brief Materials Object Libraries
+*/
+
+/*! \class materiol::cubic_tensor
     \brief \f$ 4^{th} \f$ order cubic tensor computation for materials with cubic symmetry
 
     \htmlonly 
@@ -54,9 +58,9 @@
 	and we get the following symmetries : \f$T_{ijkl} = T_{jikl} = T_{ijlk} = T_{klij} \f$.
 
     \author copyright \htmlonly &#169; \endhtmlonly 2006, 2008 Christophe COLLARD \n
-            copyright \htmlonly &#169; \endhtmlonly 2006, 2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	    copyright \htmlonly &#169; \endhtmlonly 2006 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 0.1.2
+            copyright \htmlonly &#169; 2006, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
+	    copyright \htmlonly &#169; 2006 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
+    \version 2.0.0
     \date 2006-2008
     \bug none
     \warning none
@@ -99,6 +103,10 @@
 #endif
 
 using namespace std;
+using namespace mol;
+
+namespace materiol
+{
 
 
 //=======================================================
@@ -308,4 +316,7 @@ template <class Tf> ostream& operator << (ostream& s, cubic_tensor<Tf>& tsr)
 }
 
 
+}
+
+
 #endif
