@@ -2,7 +2,7 @@
  *                   Materials Object Library                  *
  * Class isotropic_tensor : declaration for isotropic material *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 0.5.6                   *
+ *                   GNU/linux version 2.0.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright  2002,2003,2004,2005,2006,2007,2008 COLLARD Christophe
@@ -11,7 +11,11 @@
  * copyright  2002,2003,2004,2005,2006,2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
  ***************************************************************/
 
-/*! \class isotropic_tensor
+/*! \namespace materiol
+    \brief Materials Object Libraries
+*/
+
+/*! \class materiol::isotropic_tensor
     \brief \f$ 4^{th} \f$ order isotropic tensor computation
 
     \htmlonly 
@@ -42,9 +46,9 @@
 
     \author copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007, 2008 Christophe COLLARD \n
             copyright \htmlonly &#169; \endhtmlonly 2006 Cristelle PARGUEZ \n
-            copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007, 2008 Laboratoire de Physique et Mcanique des Matriaux (LPMM - UMR 7554) \n
-	    copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Mathmatiques et ses Applications de Valenciennes (LAMAV - EA 4015)
-    \version 0.5.6
+            copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007, 2008 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - UMR 7554) \endhtmlonly \n
+	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV - EA 4015) \endhtmlonly
+    \version 2.0.0
     \date 2002-2008
     \bug none
     \warning none
@@ -91,6 +95,10 @@
 #endif
 
 using namespace std;
+using namespace mol;
+
+namespace materiol
+{
 
 
 //=======================================
@@ -1323,4 +1331,7 @@ template <class T> isotropic_tensor<T>& isotropic_tensor<T>::approximation ()
 }
 
 
+}
+
+
 #endif
