@@ -1,6 +1,6 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 0.1.0                   *
+ *	             GNU/linux version 2.0.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright  2006,2007,2008 COLLARD Christophe
@@ -67,6 +67,10 @@
 #include"MateriOL++/isotropic elasticity tensors.h"
 #endif
 
+#if !defined(__CUBIC_TENSORS_H)
+#include"MateriOL++/cubic tensors.h"
+#endif
+
 #if !defined(__CUBIC_ELASTICITY_TENSORS_H)
 #include"MateriOL++/cubic elasticity tensors.h"
 #endif
@@ -75,6 +79,8 @@
 #include "tests/affiche.h"
 #endif
 
+using namespace materiol;
+
 
 //===========================================
 int test_cubic_elasticity_tensor (int detail)
@@ -106,6 +112,11 @@ int test_cubic_elasticity_tensor (int detail)
   if (detail) affiche ("material's constants", Czr.Young()==E && Czr.Shear()==mu && Czr.Poisson()==nu);
   else result *= (Czr.Young()==E && Czr.Shear()==mu && Czr.Poisson()==nu);
 
+  cubic_tensor<long double> TC (Czr(1,1,1,1), Czr(1,2,1,2), Czr(1,1,2,2));
+  cubic_elasticity_tensor<long double> TCE(TC);
+  if (detail) affiche ("copy constructor", relative_error(TCE.Young(),E) && relative_error(TCE.Shear(),mu) && relative_error(TCE.Poisson(),nu));
+  else result *= (relative_error(TCE.Young(),E) && relative_error(TCE.Shear(),mu) && relative_error(TCE.Poisson(),nu));
+
   tensor2<long double> stress(3), strain(3);
   tensor4<long double> C4 (3);
   C4 = Czr;
