@@ -1,6 +1,6 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 0.1.2                   *
+ *	             GNU/linux version 2.0.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright  2006,2007,2008 COLLARD Christophe
@@ -75,8 +75,7 @@
 #include "tests/affiche.h"
 #endif
 
-//#include "MateriOL++/MatOoLbox.h"
-//#include "MOL++/conversion tools.h"
+using namespace materiol;
 
 
 //================================
